@@ -1,5 +1,8 @@
 # https://stackoverflow.com/questions/4902974/python-import-subpackage-from-a-package-not-working
 from traquitanas.geo import converts, layers
-from traquitanas.net import downloads
+from traquitanas.net import downloads, scraping
 
-__all__ = ['geo', 'converts', 'layers', 'downloads']
+__all__ = [
+    'converts', 'layers',  # Geo
+    'downloads', 'scraping'  # Net
+]
